ICL with few-shots or many-shots if you have a large-context LLM is a must when we bootstrap any ML tasks or to compare with model finetune performances.

When ICL is used for classical ML like classification, if we have the logits of tokens, we can use `constrainded decoding` to
